html {
    height: 600px;
}

body {
    font-family: "PT Sans";
    padding-left: 1rem;
    padding-right: 1rem;
    padding-top: 1rem;
    padding-bottom: 1rem;
    height: 100%;
    background: black;
}

div {
    max-width: 100%;
    max-height: 600px;
    text-align: center;
}

div > img {
    max-height: 600px;
    max-width: 100%;
}
